@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: channel.c,v 1.62 2001/03/06 06:49:52 drscholl Exp $ */
+   $Id: channel.c,v 1.63 2001/09/22 05:52:06 drscholl Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -60,7 +60,7 @@ load_channels (void)
 	topic = next_arg (&ptr);
 	if (!name || !slimit || !slevel || !topic)
 	{
-	    log ("load_channels: %s:%d: too few parameters", path, line);
+	    log_message ("load_channels: %s:%d: too few parameters", path, line);
 	    continue;
 	}
 	/* force new channel name restrictions */
@@ -71,27 +71,27 @@ load_channels (void)
 	}
 	if (invalid_channel (name))
 	{
-	    log ("load_channels: %s:%d: %s: invalid channel name", name);
+	    log_message ("load_channels: %s:%d: %s: invalid channel name", name);
 	    continue;
 	}
 	level = get_level (slevel);
 	if (level == -1)
 	{
-	    log ("load_channels: %s:%d: %s: invalid level",
+	    log_message ("load_channels: %s:%d: %s: invalid level",
 		 path, line, slevel);
 	    continue;
 	}
 	limit = atoi (slimit);
 	if (limit < 0 || limit > 65535)
 	{
-	    log ("load_channels: %s:%d: %d: invalid limit",
+	    log_message ("load_channels: %s:%d: %d: invalid limit",
 		 path, line, limit);
 	    continue;
 	}
 	chan = hash_lookup (Channels, name);
 	if (chan)
 	{
-	    log ("load_channels: %s:%d: %s is already defined", path, line,
+	    log_message ("load_channels: %s:%d: %s is already defined", path, line,
 		 name);
 	    continue;
 	}
@@ -185,7 +185,7 @@ HANDLER (channel_ban)
 
     if (ISSERVER (con) && chan->local)
     {
-	log ("channel_ban: server %s accessed local channel %s", con->host,
+	log_message ("channel_ban: server %s accessed local channel %s", con->host,
 	     chan->name);
 	return;
     }
@@ -346,7 +346,7 @@ HANDLER (channel_clear_bans)
 
     if (ISSERVER (con) && chan->local)
     {
-	log ("clear_channel_bans: server %s accessed local channel %s",
+	log_message ("clear_channel_bans: server %s accessed local channel %s",
 	     con->host, chan->name);
 	return;
     }
@@ -520,7 +520,7 @@ HANDLER (channel_op)
     {
 	if (chan->local)
 	{
-	    log ("channel_op: server %s accessed local channel %s", con->host,
+	    log_message ("channel_op: server %s accessed local channel %s", con->host,
 		 chan->name);
 	    return;
 	}
@@ -536,9 +536,9 @@ HANDLER (channel_op)
 		if (ts > chan->timestamp)
 		{
 		    /* remote server is desynced */
-		    log ("channel_op: newer TS for channel %s from server %s",
+		    log_message ("channel_op: newer TS for channel %s from server %s",
 			    chan->name, con->host);
-		    log ("channel_op: ts=%d chan->timestamp=%u", ts,
+		    log_message ("channel_op: ts=%d chan->timestamp=%u", ts,
 			    chan->timestamp);
 		    return;	/* ignore it */
 		}
@@ -548,9 +548,9 @@ HANDLER (channel_op)
 		     * on this server, deop everyone that we know
 		     * about
 		     */
-		    log ("channel_op: older TS for channel %s from server %s",
+		    log_message ("channel_op: older TS for channel %s from server %s",
 			    chan->name, con->host);
-		    log ("channel_op: ts=%d chan->timestamp=%u", ts,
+		    log_message ("channel_op: ts=%d chan->timestamp=%u", ts,
 			    chan->timestamp);
 
 		    mass_deop (chan);
@@ -575,7 +575,7 @@ HANDLER (channel_op)
 	    else
 	    {
 		/* desync */
-		log ("channel_op: %s is not opped on channel %s",
+		log_message ("channel_op: %s is not opped on channel %s",
 			senderUser->nick, chan->name);
 	    }
 	    return;
@@ -896,7 +896,7 @@ HANDLER (channel_mode)
 	 */
 	if ((offmask & ON_CHANNEL_REGISTERED) && !chan->users)
 	{
-	    log ("channel_mode: destroying channel %s", chan->name);
+	    log_message ("channel_mode: destroying channel %s", chan->name);
 	    hash_remove (Channels, chan->name);
 	}
     }
@@ -947,7 +947,7 @@ HANDLER (channel_invite)
     }
     if (ISSERVER (con) && chan->local)
     {
-	log ("channel_invite: server %s accessed local channel %s",
+	log_message ("channel_invite: server %s accessed local channel %s",
 	     con->host, chan->name);
 	return;
     }
