@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: client_quit.c,v 1.15 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: client_quit.c,v 1.16 2001/09/22 05:52:06 drscholl Exp $ */
 
 #include "opennap.h"
 #include "debug.h"
@@ -20,7 +20,7 @@ HANDLER (client_quit)
     user = hash_lookup (Users, pkt);
     if (!user)
     {
-	log ("client_quit: can't find user %s", pkt);
+	log_message ("client_quit: can't find user %s", pkt);
 	return;
     }
     ASSERT (validate_user (user));
@@ -30,5 +30,5 @@ HANDLER (client_quit)
 	hash_remove (Users, user->nick);
     }
     else
-	log ("client_quit: recieved QUIT for local user %s!", user->nick);
+	log_message ("client_quit: recieved QUIT for local user %s!", user->nick);
 }
