@@ -2,12 +2,15 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: debug.c,v 1.20 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: debug.c,v 1.21 2001/09/24 04:06:26 drscholl Exp $ */
 
 /* This is a very simple memory management debugger.  It's useful for detecting
    memory leaks, references to uninitialzed memory, bad pointers, buffer
    overflow and getting an idea of how much memory is used by a program. */
 
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
