@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: filter.c,v 1.13 2001/03/06 06:49:52 drscholl Exp $ */
+   $Id: filter.c,v 1.15 2001/09/23 23:09:04 drscholl Exp $ */
 
 /* simple filtering mechanism to weed out entries which have too many
  * matches.  this used to be hardcoded, but various servers will need
@@ -48,7 +48,7 @@ load_filter_internal (HASH * h, const char *file)
     if (!fp)
     {
 	if (errno != ENOENT)
-	    log ("load_filter_internal: fopen: %s: %s (errno %d)",
+	    log_message ("load_filter_internal: fopen: %s: %s (errno %d)",
 		 path, strerror (errno), errno);
 	return;
     }
@@ -58,9 +58,10 @@ load_filter_internal (HASH * h, const char *file)
 	while (len > 0 && isspace (buf[len - 1]))
 	    len--;
 	buf[len] = 0;
-	/* no need to convert to lowercase since the hash table is
-	 * case-insensitive
+	/* need to convert to lowercase since the hash table is
+	 * case-sensitive
 	 */
+	strlower (buf);
 	token = STRDUP (buf);
 	hash_add (h, token, token);
     }
@@ -73,6 +74,10 @@ load_filter (void)
     if (Filter)
 	free_hash (Filter);
     Filter = hash_init (257, free_pointer);
+    /* set to case-sensitive function for speed.  we always convert to
+     * lower case before insertion.
+     */
+    hash_set_hash_func (Filter, hash_string, hash_compare_string);
     load_filter_internal (Filter, "filter");
 }
 
@@ -90,7 +95,7 @@ load_block (void)
     LIST  **head = &Block;
     int     n;
 
-    log ("load_block: free'g old list");
+    log_message ("load_block: free'g old list");
 
     while (*head)
     {
@@ -106,11 +111,11 @@ load_block (void)
     if (!fp)
     {
 	if (errno != ENOENT)
-	    log ("load_block: fopen: %s: %s (errno %d)",
+	    log_message ("load_block: fopen: %s: %s (errno %d)",
 		 path, strerror (errno), errno);
 	return;
     }
-    log ("load_block: reading %s", path);
+    log_message ("load_block: reading %s", path);
     while (fgets (buf, sizeof (buf) - 1, fp))
     {
 	line++;
@@ -133,7 +138,7 @@ load_block (void)
 	{
 	    err[0] = 0;
 	    regerror (n, rx, err, sizeof (err));
-	    log ("load_block: %s: %d: %s", path, line, err);
+	    log_message ("load_block: %s: %d: %s", path, line, err);
 	    FREE (rx);
 	    continue;
 	}
@@ -142,7 +147,7 @@ load_block (void)
 	head = &(*head)->next;
     }
     fclose (fp);
-    log ("load_block: done");
+    log_message ("load_block: done");
 }
 
 int
