@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: handler.c,v 1.113 2001/03/06 06:49:52 drscholl Exp $ */
+   $Id: handler.c,v 1.114 2001/09/22 05:52:06 drscholl Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -44,20 +44,20 @@ HANDLER (encapsulated)
     CHECK_SERVER_CLASS ("encapsulated");
     if (*pkt != ':')
     {
-	log ("encapsulated: server message does not begin with a colon (:)");
+	log_message ("encapsulated: server message does not begin with a colon (:)");
 	return;
     }
     nick = strchr (pkt + 1, ' ');
     if (!nick)
     {
-	log ("encapsulated: missing target nick");
+	log_message ("encapsulated: missing target nick");
 	return;
     }
     nick++;
     ptr = strchr (nick, ' ');
     if (!ptr)
     {
-	log ("encapsulated: missing encapsulated packet");
+	log_message ("encapsulated: missing encapsulated packet");
 	return;
     }
     ch = *ptr;
@@ -65,7 +65,7 @@ HANDLER (encapsulated)
     user = hash_lookup (Users, nick);
     if (!user)
     {
-	log ("encapsulated: no such user %s", nick);
+	log_message ("encapsulated: no such user %s", nick);
 	return;
     }
     if (user->local)
@@ -370,7 +370,7 @@ HANDLER (dispatch_command)
 	    {
 		LIST   *list;
 
-		log
+		log_message
 		    ("dispatch_command: flooding from %s!%s (numeric = %hu)",
 		     con->user->nick, con->host, tag);
 		notify_mods (FLOODLOG_MODE,
@@ -397,7 +397,7 @@ HANDLER (dispatch_command)
 	Protocol[l].bytes += len;
 	goto done;
     }
-    log ("dispatch_command: unknown message: tag=%hu, length=%hu, data=%s",
+    log_message ("dispatch_command: unknown message: tag=%hu, length=%hu, data=%s",
 	 tag, len, pkt);
     unknown_numeric.message = tag;
     unknown_numeric.count++;
@@ -461,19 +461,19 @@ handle_connection (CONNECTION * con)
 		     */
 		    if (N_ERRNO == EWOULDBLOCK)
 			break;	/* not an error */
-		    log
+		    log_message
 			("handle_connection: read: %s (errno %d) for host %s (fd %d)",
 			 strerror (N_ERRNO), N_ERRNO, con->host, con->fd);
 		}
 		else
-		    log ("handle_connection: EOF from %s", con->host);
+		    log_message ("handle_connection: EOF from %s", con->host);
 		destroy_connection (con);
 		return;
 	    }
 
 	    if (global.min_read > 0 && n < global.min_read)
 	    {
-		log ("handle_connection: %d bytes from %s", n,
+		log_message ("handle_connection: %d bytes from %s", n,
 			con->host);
 	    }
 
@@ -526,7 +526,7 @@ handle_connection (CONNECTION * con)
 	    {
 		if (N_ERRNO != EWOULDBLOCK)
 		{
-		    log
+		    log_message
 			("handle_connection: read: %s (errno %d) for host %s",
 			 strerror (N_ERRNO), N_ERRNO, con->host);
 		    destroy_connection (con);
@@ -548,7 +548,7 @@ handle_connection (CONNECTION * con)
 	{
 	    if (len > Max_Command_Length)
 	    {
-		log ("handle_connection: %hu byte message from %s",
+		log_message ("handle_connection: %hu byte message from %s",
 		     len, con->host);
 		destroy_connection (con);
 		return;
@@ -578,7 +578,7 @@ handle_connection (CONNECTION * con)
 		   next packet to arrive */
 		if (N_ERRNO != EWOULDBLOCK)
 		{
-		    log
+		    log_message
 			("handle_connection: read: %s (errno %d) for host %s",
 			 strerror (N_ERRNO), N_ERRNO, con->host);
 		    destroy_connection (con);
@@ -587,7 +587,7 @@ handle_connection (CONNECTION * con)
 	    }
 	    else if (n == 0)
 	    {
-		log ("handle_connection: EOF from %s", con->host);
+		log_message ("handle_connection: EOF from %s", con->host);
 		destroy_connection (con);
 		return;
 	    }
@@ -620,9 +620,9 @@ handle_connection (CONNECTION * con)
 	     tag != 4 &&	/* unknown: v2.0 beta 5a sends this? */
 	     tag != 300 && tag != 11 && tag != 920))
 	{
-	    log ("handle_connection: %s is not registered", con->host);
+	    log_message ("handle_connection: %s is not registered", con->host);
 	    *(con->recvbuf->data + con->recvbuf->consumed + 4 + len) = 0;
-	    log ("handle_connection: tag=%hu, len=%hu, data=%s", tag, len,
+	    log_message ("handle_connection: tag=%hu, len=%hu, data=%s", tag, len,
 		 con->recvbuf->data + con->recvbuf->consumed + 4);
 
 #if 0
