@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: join.c,v 1.87 2001/03/08 23:55:03 drscholl Exp $ */
+   $Id: join.c,v 1.88 2001/09/22 05:52:06 drscholl Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -59,7 +59,7 @@ static void
 join_desync (CONNECTION * con, const char *chan, USER * user,
 	     const char *reason)
 {
-    log ("join_desync: server %s is desynced", con->host);
+    log_message ("join_desync: server %s is desynced", con->host);
     send_cmd (con, MSG_CLIENT_KICK, ":%s %s %s \"%s\"",
 	      Server_Name, chan, user->nick, reason);
 }
@@ -123,7 +123,7 @@ HANDLER (join)
     local = (*chan_name == '&');
     if (local && ISSERVER (con))
     {
-	log ("join: server %s joined local channel %s",
+	log_message ("join: server %s joined local channel %s",
 	     user->nick, user->server, chan_name);
 	return;
     }
@@ -225,7 +225,7 @@ HANDLER (join)
 		return;
 	    }
 	    hash_add (Channels, chan->name, chan);
-	    /* log ("join: creating channel %s", chan->name); */
+	    /* log_message ("join: creating channel %s", chan->name); */
 
 	    if (ISUSER (con))
 	    {
@@ -341,7 +341,7 @@ HANDLER (join)
 			snprintf (chanbuf + strlen (chanbuf),
 				  sizeof (chanbuf) - strlen (chanbuf), "%d",
 				  n + 1);
-			log ("join: trying channel %s", chanbuf);
+			log_message ("join: trying channel %s", chanbuf);
 			continue;
 		    }
 		}
@@ -478,7 +478,7 @@ HANDLER (join)
     user->channels = list_delete (user->channels, chan);
     if (!chan->users)
     {
-	log ("join: destroying channel %s", chan->name);
+	log_message ("join: destroying channel %s", chan->name);
 	hash_remove (Channels, chan->name);
     }
     return;
@@ -543,7 +543,7 @@ HANDLER (channel_level)
 
     if (ISSERVER (con) && chan->local)
     {
-	log ("channel_level: server %s accessed local channel %s",
+	log_message ("channel_level: server %s accessed local channel %s",
 	     con->host, chan->name);
 	return;
     }
@@ -574,7 +574,7 @@ HANDLER (channel_level)
     if (desync)
     {
 	/* detected server desync, correct the mode on the remote server */
-	log ("channel_level: server %s is desynced", con->host);
+	log_message ("channel_level: server %s is desynced", con->host);
 	send_cmd (con, tag, ":%s %s %s %u",
 		  Server_Name, chan->name, Levels[chan->level],
 		  chan->timestamp);
@@ -630,7 +630,7 @@ HANDLER (channel_limit)
     }
     if (ISSERVER (con) && chan->local)
     {
-	log ("channel_limit: server %s accessed local channel %s",
+	log_message ("channel_limit: server %s accessed local channel %s",
 	     con->host, chan->name);
 	return;
     }
@@ -667,7 +667,7 @@ HANDLER (channel_limit)
     if (desync)
     {
 	/* server is out of sync, reset its limit */
-	log ("channel_limit: server %s is desynced", con->host);
+	log_message ("channel_limit: server %s is desynced", con->host);
 	send_cmd (con, tag, ":%s %s %d %u",
 		  Server_Name, chan->name, chan->limit, chan->timestamp);
 	return;
