@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: kill_user.c,v 1.50 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: kill_user.c,v 1.52 2001/03/07 21:14:31 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 #include <stdarg.h>
@@ -10,9 +14,9 @@
 #include <sys/types.h>
 #ifndef WIN32
 #include <sys/socket.h>
-#endif
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#endif
 #include "opennap.h"
 #include "debug.h"
 
