@@ -2,7 +2,11 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: list_channels.c,v 1.11 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: list_channels.c,v 1.12 2001/03/06 06:49:52 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "opennap.h"
 #include "debug.h"
