@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: login.c,v 1.188 2001/03/09 20:29:47 drscholl Exp $ */
+   $Id: login.c,v 1.191 2001/09/22 05:52:06 drscholl Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -54,7 +54,7 @@ invalid_nick (const char *s)
 static void
 sync_reginfo (USERDB * db)
 {
-    log ("sync_reginfo(): sending registration info to peers");
+    log_message ("sync_reginfo(): sending registration info to peers");
     pass_message_args (NULL, MSG_SERVER_REGINFO,
 		       ":%s %s %s %s %s %u 0", Server_Name,
 		       db->nick, db->password,
@@ -116,6 +116,8 @@ eject_client (CONNECTION * con)
     {
 	if (ISUSER (global.clients[i]) && global.clients[i] != con &&
 		!global.clients[i]->killed && /* skip already killed clients */
+		/* allow a client time to start sharing files */
+		(global.clients[i]->user->connected + EjectAfter < global.current_time) &&
 	    (global.clients[i]->user->level == LEVEL_LEECH ||
 	     (global.clients[i]->user->level == LEVEL_USER &&
 	      global.clients[i]->user->sharing <= global.eject_limit)))
@@ -223,7 +225,7 @@ HANDLER (login)
     {
 	if (ac < 5)
 	{
-	    log ("login: too few parameters (tag=%d)", tag);
+	    log_message ("login: too few parameters (tag=%d)", tag);
 	    print_args (ac, av);
 	    if (ISUNKNOWN (con))
 	    {
@@ -241,7 +243,7 @@ HANDLER (login)
 	ASSERT (ISSERVER (con));
 	if (ac < 10)
 	{
-	    log ("login: too few parameters from server %s", con->host);
+	    log_message ("login: too few parameters from server %s", con->host);
 	    if (ac > 0)
 	    {
 		/* send a kill back to this server so we stay synched. */
@@ -262,6 +264,13 @@ HANDLER (login)
 	host = realhost;
     }
 
+    if (tag == MSG_CLIENT_LOGIN_REGISTER && option (ON_RESTRICT_REGISTRATION))
+    {
+	if (ISUSER (con))
+	    send_cmd (con,MSG_SERVER_ERROR, "Automatic registration is disabled, contact server admin");
+	return;
+    }
+
     /* find info on this host */
     info = hash_lookup (Clones, (void *) ip);
     if (!info)
@@ -276,7 +285,7 @@ HANDLER (login)
 	    (global.current_time - info->last_connect < Login_Interval))
     {
 	/* client is reconnecting too fast */
-	log ("login: %s is reconnecting too fast", my_ntoa (BSWAP32 (ip)));
+	log_message ("login: %s is reconnecting too fast", my_ntoa (BSWAP32 (ip)));
 	send_cmd (con, MSG_SERVER_ERROR, "reconnecting too fast");
 	destroy_connection (con);
 	return;
@@ -312,7 +321,7 @@ HANDLER (login)
      */
     if (ISUNKNOWN (con) && (!db || db->level < LEVEL_ADMIN))
     {
-	log ("login: rejected login from %s!%s (not admin+)", av[0],
+	log_message ("login: rejected login from %s!%s (not admin+)", av[0],
 	     con->host);
 	destroy_connection (con);
 	return;
@@ -332,7 +341,7 @@ HANDLER (login)
 	 */
 	if ((clone_count = check_class (con, info)))
 	{
-	    log ("login: clones detected from %s [%d]",
+	    log_message ("login: clones detected from %s [%d]",
 		    my_ntoa (BSWAP32 (ip)), clone_count);
 	    if (ISUNKNOWN (con))
 	    {
@@ -359,7 +368,7 @@ HANDLER (login)
 		if (!option (ON_EJECT_WHEN_FULL) || !eject_client (con))
 #endif
 		{
-		    log ("login: max_connections (%d) reached",
+		    log_message ("login: max_connections (%d) reached",
 			 Max_Connections);
 		    send_cmd (con, MSG_SERVER_ERROR,
 			      "This server is full (%d connections)",
@@ -384,7 +393,7 @@ HANDLER (login)
 	notify_mods (ERROR_MODE,
 		     "Invalid speed %d for user %s from server %s", speed,
 		     av[0], con->host);
-	log ("login: invalid speed %d received from server %s", speed,
+	log_message ("login: invalid speed %d received from server %s", speed,
 	     con->host);
 	/* set to something sane.  this is only informational so its not
 	   a big deal if we are out of synch */
@@ -403,7 +412,7 @@ HANDLER (login)
 	ASSERT (ISSERVER (con));
 	notify_mods (ERROR_MODE, "Invalid port %d for user %s from server %s",
 		     port, av[0], con->host);
-	log ("login: invalid port %d received from server %s",
+	log_message ("login: invalid port %d received from server %s",
 	     port, con->host);
 	port = 0;
 	/* TODO: generate a change port command */
@@ -458,7 +467,7 @@ HANDLER (login)
 	/* check the user's password */
 	if (check_pass (db->password, av[1]))
 	{
-	    log ("login: bad password for %s (%s) from %s",
+	    log_message ("login: bad password for %s (%s) from %s",
 		 db->nick, Levels[db->level], host);
 
 	    if (ISUNKNOWN (con))
@@ -550,7 +559,7 @@ HANDLER (login)
 		/* the client we already know about is older, reject
 		 * this login
 		 */
-		log
+		log_message
 		    ("login: nick collision for user %s, rejected login from server %s",
 		     user->nick, con->host);
 #if 0
@@ -571,7 +580,7 @@ HANDLER (login)
 		(global.current_time - info->last_register < Register_Interval))
 	{
 	    /* client is attempting to register nicks too fast */
-	    log ("login: %s is registering nicks too fast",
+	    log_message ("login: %s is registering nicks too fast",
 		    my_ntoa (BSWAP32 (ip)));
 	    send_cmd (con, MSG_SERVER_ERROR, "reregistering too fast");
 	    destroy_connection (con);
@@ -612,7 +621,7 @@ HANDLER (login)
 	db->lastSeen = global.current_time;
 	if (hash_add (User_Db, db->nick, db))
 	{
-	    log ("login: hash_add failed (ignored)");
+	    log_message ("login: hash_add failed (ignored)");
 	    userdb_free (db);
 	    db = NULL;
 	}
@@ -687,7 +696,7 @@ HANDLER (login)
 
     if (hash_add (Users, user->nick, user))
     {
-	log ("login(): hash_add failed (fatal)");
+	log_message ("login(): hash_add failed (fatal)");
 	goto failed;
     }
 
@@ -802,7 +811,7 @@ HANDLER (register_nick)
     ASSERT (validate_connection (con));
     if (con->class != CLASS_UNKNOWN)
     {
-	log ("register_nick(): command received after registration");
+	log_message ("register_nick(): command received after registration");
 	send_cmd (con, MSG_SERVER_NOSUCH, "You are already logged in.");
 	return;
     }
@@ -833,7 +842,7 @@ HANDLER (reginfo)
 
     if (*pkt != ':')
     {
-	log ("reginfo: message does not begin with :");
+	log_message ("reginfo: message does not begin with :");
 	return;
     }
     pkt++;
@@ -843,7 +852,7 @@ HANDLER (reginfo)
 
     if (ac < 5)
     {
-	log ("reginfo: wrong number of fields");
+	log_message ("reginfo: wrong number of fields");
 	return;
     }
     /* look up any entry we have for this user */
@@ -856,7 +865,7 @@ HANDLER (reginfo)
 	if (atol (fields[4]) > db->created)
 	{
 	    /* our record was created first, notify peers */
-	    log ("reginfo: stale reginfo received from %s", server);
+	    log_message ("reginfo: stale reginfo received from %s", server);
 	    sync_reginfo (db);
 	    return;
 	}
@@ -870,7 +879,7 @@ HANDLER (reginfo)
     {
 	if (invalid_nick (fields[0]))
 	{
-	    log ("reginfo: received invalid nickname");
+	    log_message ("reginfo: received invalid nickname");
 	    return;
 	}
 	db = CALLOC (1, sizeof (USERDB));
@@ -888,7 +897,7 @@ HANDLER (reginfo)
     level = get_level (fields[3]);
     if (level == -1)
     {
-	log ("reginfo: invalid level %s", fields[3]);
+	log_message ("reginfo: invalid level %s", fields[3]);
 	level = LEVEL_USER;	/* reset to something reasonable */
     }
 
@@ -1050,7 +1059,7 @@ HANDLER (ignore_command)
     (void) con;
     /* just ignore this message for now */
 #if 0
-    log ("ignore_command: (client=%s) tag=%d, len=%d, data=%s",
+    log_message ("ignore_command: (client=%s) tag=%d, len=%d, data=%s",
 	 ISUSER (con) ? con->user->clientinfo : "(unknown)", tag, len, pkt);
 #endif
 }
@@ -1080,5 +1089,5 @@ void
 cleanup_ip_info (void)
 {
     hash_foreach (Clones, (hash_callback_t) cleanup_ip_info_cb, NULL);
-    log ("cleanup_ip_info: %d addresses in the table", Clones->dbsize);
+    log_message ("cleanup_ip_info: %d addresses in the table", Clones->dbsize);
 }
