@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: main.c,v 1.305 2001/03/09 08:37:48 drscholl Exp $ */
+   $Id: main.c,v 1.314 2001/09/30 22:07:07 drscholl Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -60,6 +60,7 @@ int     Compression_Level = 0;
 char   *Config_Dir = SHAREDIR;
 u_int   Connection_Count = 0;
 LIST   *Destroy = 0;
+int	EjectAfter;
 int     Flood_Commands;
 int     Flood_Time;
 LIST   *Flooders = 0;
@@ -109,6 +110,8 @@ int     File_Count_Threshold;
 HASH   *File_Table;		/* global file list */
 int     Local_Files = 0;	/* number of files shared by local users */
 int     Max_Shared;
+int     Index_Path_Depth;	/* how many levels including the filename to
+				   include when indexing */
 
 #if RESUME
 HASH   *MD5;			/* global hash list */
@@ -136,8 +139,6 @@ LIST   *Server_Links = 0;
 /* Cache of server names for caching the user->server pointers */
 LIST   *Server_Names = 0;
 
-#define BACKLOG 50
-
 void
 set_write (int fd)
 {
@@ -337,7 +338,7 @@ report_stats (int fd)
 	nlogerr ("report_stats", "accept");
 	return;
     }
-    log ("report_stats: connection from %s:%d", inet_ntoa (sin.sin_addr),
+    log_message ("report_stats: connection from %s:%d", inet_ntoa (sin.sin_addr),
 	 htons (sin.sin_port));
 #ifdef linux
     {
@@ -350,7 +351,7 @@ report_stats (int fd)
 	}
 	else
 	{
-	    log ("report_stats: /proc/loadavg: %s (errno %d)",
+	    log_message ("report_stats: /proc/loadavg: %s (errno %d)",
 		 strerror (errno), errno);
 	}
     }
@@ -372,32 +373,32 @@ update_stats (void)
 
     strcpy (Buf, ctime (&Server_Start));
     Buf[strlen (Buf) - 1] = 0;
-    log ("update_stats: server was started on %s", Buf);
+    log_message ("update_stats: server was started on %s", Buf);
     strcpy (Buf, ctime (&global.current_time));
 
     Buf[strlen (Buf) - 1] = 0;
-    log ("update_stats: current time is %s", Buf);
-    log ("update_stats: library is %d GB, %d files, %d users",
+    log_message ("update_stats: current time is %s", Buf);
+    log_message ("update_stats: library is %d GB, %d files, %d users",
 	 (int) (Num_Gigs / 1048576.), Num_Files, Users->dbsize);
-    log ("update_stats: %d local clients, %d linked servers",
+    log_message ("update_stats: %d local clients, %d linked servers",
 	 global.clients_num - numServers, numServers);
 
 #ifndef ROUTING_ONLY
-    log ("update_stats: %d local files", Local_Files);
-    log ("update_stats: File_Table contains %d entries", File_Table->dbsize);
+    log_message ("update_stats: %d local files", Local_Files);
+    log_message ("update_stats: File_Table contains %d entries", File_Table->dbsize);
 #endif
     if (delta > 0)
-	log ("update_stats: %d searches/sec", global.search_count / delta);
+	log_message ("update_stats: %d searches/sec", global.search_count / delta);
 
-    log ("update_stats: User_Db contains %d entries", User_Db->dbsize);
-    log ("update_stats: %d channels", Channels->dbsize);
+    log_message ("update_stats: User_Db contains %d entries", User_Db->dbsize);
+    log_message ("update_stats: %d channels", Channels->dbsize);
     if (delta > 0)
-	log ("update_stats: %d kbytes/sec in, %d kbytes/sec out",
+	log_message ("update_stats: %d kbytes/sec in, %d kbytes/sec out",
 	     (int) (global.bytes_in / 1024 / delta),
 	     (int) (global.bytes_out / delta / 1024));
     global. total_bytes_in += global.bytes_in;
     global. total_bytes_out += global.bytes_out;
-    log ("update_stats: %.0f bytes sent, %.0f bytes received",
+    log_message ("update_stats: %.0f bytes sent, %.0f bytes received",
 	 global.total_bytes_out, global.total_bytes_in);
 
     /* reset counters */
@@ -450,7 +451,7 @@ accept_connection (int s)
 
 	if (!acl_connection_allowed (BSWAP32 (sin.sin_addr.s_addr)))
 	{
-	    log ("accept_connection: connection from %s denied by ACLs",
+	    log_message ("accept_connection: connection from %s denied by ACLs",
 		 inet_ntoa (sin.sin_addr));
 	    CLOSE (f);
 	    continue;
@@ -571,7 +572,7 @@ args (int argc, char **argv, int *sockfdcount)
 		Config_Dir = optarg;
 	    else
 	    {
-		log ("args: can't use -c when run as root");
+		log_message ("args: can't use -c when run as root");
 		exit (1);
 	    }
 	    break;
@@ -593,7 +594,7 @@ args (int argc, char **argv, int *sockfdcount)
 	    }
 	    else
 	    {
-		log ("args: privileged ports not allowed on command line");
+		log_message ("args: privileged ports not allowed on command line");
 		exit (1);
 	    }
 	    break;
@@ -650,7 +651,7 @@ args (int argc, char **argv, int *sockfdcount)
     if (disable_remote)
 	    Server_Flags &= ~ON_REMOTE_CONFIG;
     if (!(Server_Flags & ON_REMOTE_CONFIG))
-	    log("args: remote configuration disabled");
+	    log_message("args: remote configuration disabled");
 
     /* if the interface was specified on the command line, override the
      * value from the config file
@@ -671,12 +672,12 @@ args (int argc, char **argv, int *sockfdcount)
     /* ensure at least one valid port */
     if (*sockfdcount < 1)
     {
-	log ("args: no server ports defined");
+	log_message ("args: no server ports defined");
 	exit (1);
     }
     sockfd = CALLOC (*sockfdcount, sizeof (int));
 
-    log ("args: listening on %d sockets", *sockfdcount);
+    log_message ("args: listening on %d sockets", *sockfdcount);
     for (i = 0, tmpList = ports; i < *sockfdcount;
 	 i++, tmpList = tmpList->next)
     {
@@ -684,12 +685,12 @@ args (int argc, char **argv, int *sockfdcount)
 	    exit (1);
 	if (bind_interface (sockfd[i], Interface, atoi (tmpList->data)) == -1)
 	    exit (1);
-	if (listen (sockfd[i], BACKLOG) < 0)
+	if (listen (sockfd[i], SOMAXCONN) < 0)
 	{
 	    nlogerr ("args", "listen");
 	    exit (1);
 	}
-	log ("args: listening on %s port %d", my_ntoa (Interface),
+	log_message ("args: listening on %s port %d", my_ntoa (Interface),
 	     atoi (tmpList->data));
 	if (sockfd[i] > global.max_fd)
 	    global. max_fd = sockfd[i];
@@ -724,7 +725,7 @@ init_stats_port (void)
 	    exit (1);
 	if (bind_interface (sp, Interface, Stats_Port))
 	    exit (1);
-	if (listen (sp, BACKLOG))
+	if (listen (sp, SOMAXCONN))
 	{
 	    logerr ("main", "listen");
 	    exit (1);
@@ -759,10 +760,10 @@ destroy_connection (CONNECTION * con)
 	list = list_find (Destroy, con);
 	if (list)
 	    return;		/* already destroyed */
-	log ("destroy_connection: error, destroyed connection not on Destroy list");
-	log ("destroy_connection: con->host = %s", con->host);
+	log_message ("destroy_connection: error, destroyed connection not on Destroy list");
+	log_message ("destroy_connection: con->host = %s", con->host);
 	if (ISUSER (con))
-	    log ("destroy_connection: con->user->nick = %s", con->user->nick);
+	    log_message ("destroy_connection: con->user->nick = %s", con->user->nick);
     }
     else
 	num_reaped++;
@@ -829,6 +830,10 @@ reap_dead_connection (CONNECTION * con)
     /* mark that the descriptor has been closed */
     con->fd = -1;
 
+    /* remove from flood list (if present) */
+    if (Flooders)
+	Flooders = list_delete (Flooders, con);
+
     /* this call actually free's the memory associated with the connection */
     remove_connection (con);
 }
@@ -933,6 +938,7 @@ main (int argc, char **argv)
 #else
     struct timeval to;
     fd_set  read_fds, write_fds;
+    int selectErrors = 0;
 #endif
 
 #if defined(WIN32) && !defined(__CYGWIN__)
@@ -1014,7 +1020,7 @@ main (int argc, char **argv)
 	/* if we have a flood list and the timeout is greater than when
 	 * the flood expires, reset the timeout
 	 */
-	if (Flooders && TIMEOUT > Flood_Time)
+	if (Flooders && Flood_Time > 0 && TIMEOUT > Flood_Time)
 	    TIMEOUT = Flood_Time;
 
 #if HAVE_POLL
@@ -1051,8 +1057,15 @@ main (int argc, char **argv)
 	if (numfds == -1)
 	{
 	    nlogerr ("main", "select");
+	    if (++selectErrors == 5)
+	    {
+		logerr ("main", "too many errors, exiting...");
+		break;
+	    }
 	    continue;
 	}
+
+	selectErrors = 0; /* reset */
 #endif
 
 	/* pre-read server links */
@@ -1084,13 +1097,13 @@ main (int argc, char **argv)
 
 		    else
 		    {
-			log ("main: fd %d (%s): %s (errno %d)",
+			log_message ("main: fd %d (%s): %s (errno %d)",
 			     global.poll[off].fd,
 			     global.clients[i]->host, strerror (err), err);
 		    }
 		}
 		else
-		    log ("main: fd %d %s", global.poll[off].fd,
+		    log_message ("main: fd %d %s", global.poll[off].fd,
 			 (global.poll[off].
 			  revents & POLLNVAL) ? "is invalid" : "got hangup");
 
@@ -1118,7 +1131,7 @@ main (int argc, char **argv)
 		    if (!ISSERVER (global.clients[i])
 			&& !global.clients[i]->sendbuf)
 		    {
-			log ("main: ERROR, fd %d (id %d) was writable with no pending data",
+			log_message ("main: ERROR, fd %d (id %d) was writable with no pending data",
 				global.clients[i]->fd, global.clients[i]->id);
 			clear_write (global.clients[i]->fd);
 		    }
@@ -1136,7 +1149,7 @@ main (int argc, char **argv)
 		global.current_time - global.clients[i]->timer >
 		Login_Timeout)
 	    {
-		log ("main: terminating %s (login timeout)",
+		log_message ("main: terminating %s (login timeout)",
 		     global.clients[i]->host);
 		send_cmd (global.clients[i], MSG_SERVER_ERROR,
 			  "Idle timeout");
@@ -1170,7 +1183,7 @@ main (int argc, char **argv)
 		}
 		else if (code)
 		{
-		    log ("main: connection to stat server failed (%s)",
+		    log_message ("main: connection to stat server failed (%s)",
 			    strerror (code));
 #if HAVE_POLL
 		    remove_fd (global.stat_server_fd);
@@ -1276,7 +1289,7 @@ main (int argc, char **argv)
 #endif
 
     global. current_time = time (0);
-    log ("main: server ended at %s", ctime (&global.current_time));
+    log_message ("main: server ended at %s", ctime (&global.current_time));
 
     exit (0);
 }
