@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: napigator.c,v 1.7 2001/03/12 18:02:54 drscholl Exp $ */
+   $Id: napigator.c,v 1.8 2001/09/22 05:52:06 drscholl Exp $ */
 
 /*** support for Napigator ***/
 
@@ -37,7 +37,7 @@ stat_server_read (void)
     {
 	if (n == -1)
 	    logerr ("stat_server_read", "read");
-	log ("stat_server_read: got hangup");
+	log_message ("stat_server_read: got hangup");
 	do_close = 1;
     }
     else
@@ -58,7 +58,7 @@ stat_server_read (void)
 	    salt = next_arg (&p);
 	    if (!salt)
 	    {
-		log ("stat_server_read:unable to get salt string");
+		log_message ("stat_server_read:unable to get salt string");
 		strcpy (Buf, "QUIT\r\n");
 		WRITE (global.stat_server_fd, Buf, strlen (Buf));
 	    }
@@ -98,7 +98,7 @@ stat_server_read (void)
 	else if (n == 201)
 	{
 	    /* auth complete */
-	    log ("stat_server_read: logged in");
+	    log_message ("stat_server_read: logged in");
 
 	    /* send updated ip:port in case we are a dynamic server */
 	    snprintf (Buf, sizeof (Buf), "IPPORT %s %s %d\r\n",
@@ -113,7 +113,7 @@ stat_server_read (void)
 	else if (n / 100 >= 4)
 	{
 	    /* something failed */
-	    log ("stat_server_read:%s", Buf);
+	    log_message ("stat_server_read:%s", Buf);
 	    strcpy (Buf, "QUIT\r\n");
 	    WRITE (global.stat_server_fd, Buf, strlen (Buf));
 	}
@@ -123,13 +123,13 @@ stat_server_read (void)
 	}
 	else
 	{
-	    log ("stat_server_read: unhandled:%s", Buf);
+	    log_message ("stat_server_read: unhandled:%s", Buf);
 	}
     }
 
     if (do_close)
     {
-	log ("stat_server_read: closing connection");
+	log_message ("stat_server_read: closing connection");
 	CLOSE (global.stat_server_fd);
 #if HAVE_POLL
 	remove_fd (global.stat_server_fd);
@@ -170,7 +170,7 @@ stat_server_push (void)
 
     if (WRITE (global.stat_server_fd, Buf, strlen (Buf)) == -1)
     {
-	log ("stat_server_push: write: %s (%d)", strerror (N_ERRNO), N_ERRNO);
+	log_message ("stat_server_push: write: %s (%d)", strerror (N_ERRNO), N_ERRNO);
 	CLOSE (global.stat_server_fd);
 #if HAVE_POLL
 	remove_fd (global.stat_server_fd);
