@@ -2,17 +2,13 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: opennap.h,v 1.300 2001/03/09 20:17:18 drscholl Exp $ */
+   $Id: opennap.h,v 1.309 2001/09/30 22:07:07 drscholl Exp $ */
 
 #ifndef opennap_h
 #define opennap_h
 
-#if defined(WIN32) && !defined(__CYGWIN__)
-#include <windows.h>
-/* the next two #defines are needed for zlib */
-#define _WINDOWS
-#define ZLIB_DLL
-#include "zlib.h"
+#if defined (WIN32) && !defined (__CYGWIN__)
+#include "win32-support.h"
 #endif
 
 #if HAVE_POLL
@@ -25,8 +21,8 @@
 #include "hash.h"
 #include "list.h"
 
-#define OUTOFMEMORY(f) log("%s: OUT OF MEMORY at %s:%d", f, __FILE__, __LINE__)
-#define _logerr(f,s,e) log("%s: %s: %s (errno %d)", f, s, strerror(e), e)
+#define OUTOFMEMORY(f) log_message("%s: OUT OF MEMORY at %s:%d", f, __FILE__, __LINE__)
+#define _logerr(f,s,e) log_message("%s: %s: %s (errno %d)", f, s, strerror(e), e)
 #define logerr(f,s) _logerr(f,s,errno)
 
 #define MAGIC_USER 0xeaee402a
@@ -52,7 +48,6 @@
 
 #define FIELDS(p) sizeof(p)/sizeof(char*)
 
-
 typedef struct _buffer BUFFER;
 
 /* to avoid copying a lot of data around with memmove() we use the following
@@ -274,6 +269,13 @@ struct _connection
 
 };
 
+/* doubly linked list */
+typedef struct _DList {
+    struct _DList *prev;
+    struct _DList *next;
+    void *data;
+} DList;
+
 /* list of DATUM entries, used in the global file list */
 typedef struct
 {
@@ -281,10 +283,23 @@ typedef struct
     unsigned int magic;
 #endif
     char   *key;		/* keyword */
-    LIST   *list;		/* list of files containing this keyword */
+    DList   *list;		/* list of files containing this keyword */
     int     count;		/* number of files in the list */
 }
-FLIST;
+FileList;
+
+/* Each DATUM contains a list of all the `tokens' it contains.  Since the
+ * list of files in each token can be very large (~thousands on a busy
+ * server), deletion of a particular DATUM from the FileList would involve
+ * scanning the entire list.  Instead, we store a pointer to the element
+ * itself so we can remove it quickly.  Previously, when a user with a large
+ * shared collection quit the server, there would be a noticeable pause
+ * with all the list scanning that occurred.
+ */
+typedef struct {
+    FileList *flist;	/* bin in which this file resides */
+    DList *dlist;	/* reference to this file for quick deletion */
+} TokenRef;
 
 /* content-type */
 enum
@@ -298,6 +313,11 @@ enum
     CT_UNKNOWN
 };
 
+/* maximum number of words a file can be indexed under.  currently we have 5-bits of storage for
+ * the number of tokens.
+ */
+#define kOMaxTokens 31 /* 0 , 2^5 - 1 */
+
 typedef struct
 {
     USER   *user;		/* user who possesses this file */
@@ -305,7 +325,8 @@ typedef struct
 #if RESUME
     char   *hash;		/* the md5 hash of the file */
 #endif
-    LIST   *tokens;		/* list of keywords for this file */
+    TokenRef   *tokens;		/* array of keywords for this file */
+    
     unsigned int size;		/* size of file in bytes.  set to -1 if
 				   the structure is invalid */
     unsigned short duration;
@@ -313,7 +334,7 @@ typedef struct
     unsigned int bitrate:5;	/* offset into BitRate[] */
     unsigned int frequency:3;	/* offset into SampleRate[] */
     unsigned int type:3;	/* content type */
-    unsigned int xxx:5;		/* unused */
+    unsigned int numTokens:5;		/* # of entries in the TokenRef array */
 }
 DATUM;
 
@@ -452,6 +473,7 @@ extern global_t global;
 
 #ifndef ROUTING_ONLY
 extern int File_Count_Threshold;
+extern int Index_Path_Depth;
 extern HASH *File_Table;
 extern HASH *Filter;
 extern int Local_Files;
@@ -471,6 +493,7 @@ extern HASH *Clones;
 extern int Compression_Level;
 extern char *Config_Dir;
 extern unsigned int Connection_Count;
+extern int EjectAfter;
 extern int Flood_Commands;
 extern int Flood_Time;
 extern LIST *Flooders;
@@ -545,6 +568,8 @@ extern int Max_Rss_Size;
 #define ON_GHOST_KILL		(1<<11)	/* enable auto ghost kill */
 #define ON_ALLOW_SHARE		(1<<12)	/* allow file sharing */
 #define ON_REMOTE_CONFIG	(1<<13)	/* is remote configuration allowed ? */
+#define ON_IGNORE_SUFFIX	(1<<14) /* ignore file suffix when indexing? */
+#define ON_RESTRICT_REGISTRATION (1<<15) /* disallow auto client registration */
 
 extern char Buf[2048];
 
@@ -863,7 +888,7 @@ void    load_channels (void);
 int     load_class (void);
 void    load_filter (void);
 void    load_server_auth (void);
-void    log (const char *fmt, ...);
+void    log_message (const char *fmt, ...);
 unsigned int lookup_ip (const char *host);
 int     make_tcp_connection (const char *host, int port, unsigned int *ip);
 void    motd_init (void);
@@ -914,6 +939,7 @@ int     set_rss_size (int);
 int     set_tcp_buffer_len (int, int);
 void    set_write (int);
 int     split_line (char **template, int templatecount, char *pkt);
+char   *split_filename (char *fqfn);
 void    stat_server_push (void);
 void    stat_server_read (void);
 char   *strfcpy (char *, const char *, size_t);
@@ -936,7 +962,7 @@ void    config_user_level (char *);
 int     validate_user (USER *);
 int     validate_channel (CHANNEL *);
 int     validate_connection (CONNECTION *);
-int     validate_flist (FLIST *);
+int     validate_flist (FileList *);
 #endif
 
 #define HANDLER(f) void f (CONNECTION *con, unsigned short tag, u_short len, char *pkt)
@@ -1062,8 +1088,8 @@ HANDLER (which_server);
 HANDLER (who_was);
 HANDLER (whois_notify);
 
-#define CHECK_USER_CLASS(f) if (con->class != CLASS_USER) { log ("%s: not USER class", f); return; }
-#define CHECK_SERVER_CLASS(f) if(con->class != CLASS_SERVER) { log ("%s: not SERVER class", f); return; }
+#define CHECK_USER_CLASS(f) if (con->class != CLASS_USER) { log_message ("%s: not USER class", f); return; }
+#define CHECK_SERVER_CLASS(f) if(con->class != CLASS_SERVER) { log_message ("%s: not SERVER class", f); return; }
 
 #define NONULL(p) (p!=0?p:"")
 
@@ -1078,7 +1104,7 @@ typedef unsigned int socklen_t;
 
 #ifdef __sun__
 #define SOCKOPTCAST (char*)
-#else
+#elif !defined SOCKOPTCAST
 #define SOCKOPTCAST
 #endif /* __sun__ */
 
@@ -1094,37 +1120,14 @@ typedef unsigned int socklen_t;
 #define N_ERRNO errno
 /* log message for errors with socket related system calls */
 #define nlogerr logerr
+
 #else
-#define READ(a,b,c) recv(a,b,c,0)
-#define WRITE(a,b,c) send(a,b,c,0)
-#define CLOSE closesocket
-#undef SOCKOPTCAST
-#define SOCKOPTCAST (char*)
-#define EINPROGRESS WSAEINPROGRESS
-#define EWOULDBLOCK WSAEWOULDBLOCK
-#define ENOBUFS WSAENOBUFS
-#define _POSIX_PATH_MAX 256
+
 /* winsock uses h_errno so we have to wrap the test for it here */
 #define N_ERRNO h_errno
 #define nlogerr(f,s) _logerr(f,s,h_errno)
 
 #define SHAREDIR "C:\\opennap"
-#define PACKAGE "opennap"
-#define VERSION "0.42"
-
-#define strcasecmp stricmp
-#define strncasecmp strnicmp
-#define vsnprintf _vsnprintf
-#define snprintf _snprintf
-#define getuid() 0		/* just fake it */
-#define getpid() 0		/* just fake it */
-
-extern int _getopt (int, char **, char *);
-
-#define getopt _getopt
-
-extern char *optarg;
-extern int optind;
 
 #endif /* !WIN32 */
 
