@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: remove_file.c,v 1.34 2001/03/06 06:49:53 drscholl Exp $ */
+   $Id: remove_file.c,v 1.36 2001/09/22 05:52:06 drscholl Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -20,7 +20,6 @@ HANDLER (remove_file)
     USER   *user;
     DATUM  *info;
     unsigned int fsize;
-    char *arg;
 
     (void) tag;
     (void) len;
@@ -33,15 +32,15 @@ HANDLER (remove_file)
 	return;
     }
 
-    arg = next_arg (&pkt);
-    if (!arg)
+    ASSERT (pkt != 0);
+    if (!*pkt)
     {
 	send_cmd (con, MSG_SERVER_NOSUCH, "remove file failed: missing argument");
 	return;
     }
 
     /* find the file in the user's list */
-    info = hash_lookup (con->uopt->files, arg);
+    info = hash_lookup (con->uopt->files, pkt);
     if (!info)
     {
 	send_cmd (con, MSG_SERVER_NOSUCH, "Not sharing that file");
@@ -53,7 +52,7 @@ HANDLER (remove_file)
 
     if (fsize > user->libsize)
     {
-	log ("remove_file: bad lib size for %s, fsize=%u user->libsize=%u",
+	log_message ("remove_file: bad lib size for %s, fsize=%u user->libsize=%u",
 	     user->nick, fsize, user->libsize);
 	user->libsize = fsize;	/* prevent negative count */
     }
@@ -61,7 +60,7 @@ HANDLER (remove_file)
 
     if (fsize > Num_Gigs)
     {
-	log ("remove_file: bad lib size for %s, fsize=%u Num_Gigs=%f",
+	log_message ("remove_file: bad lib size for %s, fsize=%u Num_Gigs=%f",
 	     user->nick, fsize, Num_Gigs);
 	Num_Gigs = fsize;	/* prevent negative count */
     }
