@@ -2,7 +2,7 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: search.c,v 1.130 2001/07/06 04:03:28 drscholl Exp $ */
+   $Id: search.c,v 1.135 2001/09/28 22:55:14 drscholl Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -49,7 +49,7 @@ search_end (CONNECTION * con, const char *id)
     {
 	if (con->uopt->searches <= 0)
 	{
-	    log ("search_end: ERROR, con->uopt->searches <= 0!!!!!!");
+	    log_message ("search_end: ERROR, con->uopt->searches <= 0!!!!!!");
 	    con->uopt->searches = 0;
 	}
 	else
@@ -298,35 +298,51 @@ tokenize (char *s, LIST ** exclude_list)
     return r;
 }
 
+/* remove this datum from the lists for each keyword it is indexed under */
 void
 free_datum (DATUM * d)
 {
-    LIST   *list, *tmp;
-    FLIST  *flist;
+    int i;
+    TokenRef *ref;
 
-    /* remove this datum from the lists for each keyword it is indexed
-     * under
-     */
-    list = d->tokens;
-    while (list)
+    for (i = 0; i < d->numTokens; i++)
     {
-	flist = list->data;
-	ASSERT (validate_flist (flist));
-	flist->list = list_delete (flist->list, d);
-	flist->count--;
-	/* if there are no more files in this bin, erase it */
-	if (flist->count == 0)
+	ref = &d->tokens[i];
+
+	ASSERT (validate_flist (ref->flist));
+
+	/* de-link the element pointing to this file */
+	if (ref->dlist->prev)
+	    ref->dlist->prev->next = ref->dlist->next;
+	else
 	{
-	    ASSERT (flist->list == 0);
-	    hash_remove (File_Table, flist->key);
-	    FREE (flist->key);
-	    FREE (flist);
+	    /* this is the head of the list, update the flist struct.  if
+	     * we just free this pointer, the flist struct would have a bogus
+	     * pointer
+	     */
+	    ref->flist->list = ref->dlist->next;
+	}
+
+	/* update the back pointer of the next element (if it exists) */
+	if (ref->dlist->next)
+	    ref->dlist->next->prev = ref->dlist->prev;
+
+	FREE (ref->dlist);
+
+	ref->flist->count--;
+	/* if there are no more files in this bin, erase it */
+	if (ref->flist->count == 0)
+	{
+	    ASSERT (ref->flist->list == 0);
+	    hash_remove (File_Table, ref->flist->key);
+	    FREE (ref->flist->key);
+	    FREE (ref->flist);
 	}
-	tmp = list;
-	list = list->next;
-	FREE (tmp);
     }
 
+    FREE (d->tokens);
+
+    /* XXX broken */
 #if RESUME
     flist = hash_lookup (MD5, d->hash);
     if (flist)
@@ -344,7 +360,7 @@ free_datum (DATUM * d)
 	}
     }
     else
-	log ("free_datum: error, no hash entry for file %s", d->filename);
+	log_message ("free_datum: error, no hash entry for file %s", d->filename);
     FREE (d->hash);
 #endif
 
@@ -352,17 +368,29 @@ free_datum (DATUM * d)
     FREE (d);
 }
 
+static int
+sContainsFileList (DATUM *d, FileList *f)
+{
+    int i;
+
+    for (i = 0; i < d->numTokens; i++)
+	if (d->tokens[i].flist == f)
+	    return 1;
+    return 0;
+}
+
 static int
 fdb_search (LIST * contains, LIST * excludes, int maxhits, SEARCH * crit)
 {
     LIST   *words = 0;		/* matched words */
     LIST   *exclude_words = 0;	/* words NOT to match */
-    LIST   *ptok;
-    FLIST  *flist = 0, *tmp;
-    DATUM  *d;
-    int     hits = 0;
+    LIST **listptr;
     LIST   *list;		/* temp pointer for creation of `words' list */
     LIST   *pWords;		/* iteration pointer for `words' list */
+    DList   *ptok;
+    FileList  *flist = 0, *tmp;
+    DATUM  *d;
+    int     hits = 0;
     int     is_match;
 
     Search_Count++;
@@ -372,14 +400,15 @@ fdb_search (LIST * contains, LIST * excludes, int maxhits, SEARCH * crit)
 	/* this shouldn't happen because we catch this condition down where
 	 * fdb_search() is called and report it back to the user
 	 */
-	log ("fdb_search: error, tokens==NULL");
+	log_message ("fdb_search: error, tokens==NULL");
 	return 0;
     }
 
     /* find the file list with the fewest files in it */
-    for (ptok = contains; ptok; ptok = ptok->next)
+    listptr = &words;
+    for (list = contains; list; list = list->next)
     {
-	tmp = hash_lookup (File_Table, ptok->data);
+	tmp = hash_lookup (File_Table, list->data);
 	if (!tmp)
 	{
 	    /* if there is no entry for this word in the hash table, then
@@ -395,7 +424,7 @@ fdb_search (LIST * contains, LIST * excludes, int maxhits, SEARCH * crit)
 	    flist = tmp;
 	else if (flist->count >= File_Count_Threshold)
 	{
-	    log ("fdb_search: token \"%s\" contains %d files",
+	    log_message ("fdb_search: token \"%s\" contains %d files",
 		 flist->key, flist->count);
 	}
 
@@ -403,27 +432,35 @@ fdb_search (LIST * contains, LIST * excludes, int maxhits, SEARCH * crit)
 	 * later to ensure that all of these tokens appear in the files we
 	 * are considering as possible matches
 	 */
-	list = CALLOC (1, sizeof (LIST));
-	if (!list)
+	*listptr = CALLOC (1, sizeof (LIST));
+	if (!*listptr)
 	{
 	    OUTOFMEMORY ("fdb_search");
 	}
 	else
 	{
-	    list->data = tmp;	/* current word */
-	    words = list_push (words, list);
+	    (*listptr)->data = tmp;	/* current word */
+	    listptr = &(*listptr)->next;
 	}
     }
 
     /* find the list of words to exclude, if any */
-    for (ptok = excludes; ptok; ptok = ptok->next)
+    listptr = &exclude_words;
+    for (list = excludes; list; list = list->next)
     {
-	tmp = hash_lookup (File_Table, ptok->data);
+	tmp = hash_lookup (File_Table, list->data);
 	if (tmp)
 	{
-	    list = CALLOC (1, sizeof (LIST));
-	    list->data = tmp;
-	    exclude_words = list_push (exclude_words, list);
+	    *listptr = CALLOC (1, sizeof (LIST));
+	    if (!*listptr)
+	    {
+		OUTOFMEMORY ("fdb_search");
+	    }
+	    else
+	    {
+		(*listptr)->data = tmp;
+		listptr = &(*listptr)->next;
+	    }
 	}
     }
 
@@ -451,7 +488,8 @@ fdb_search (LIST * contains, LIST * excludes, int maxhits, SEARCH * crit)
 	     * of the list.  skip the word we are matching on since we
 	     * know its there.
 	     */
-	    if (pWords->data != d && list_find (d->tokens, pWords->data) == 0)
+	    if (pWords->data != flist &&
+		    !sContainsFileList (d, pWords->data))
 	    {
 		is_match = 0;
 		break;
@@ -466,7 +504,7 @@ fdb_search (LIST * contains, LIST * excludes, int maxhits, SEARCH * crit)
 	 */
 	for (pWords = exclude_words; pWords; pWords = pWords->next)
 	{
-	    if (list_find (d->tokens, pWords->data))
+	    if (sContainsFileList (d, pWords->data))
 	    {
 		/* file contains a bad word */
 		is_match = 0;
@@ -729,7 +767,9 @@ search_internal (CONNECTION * con, USER * user, char *id, char *pkt)
 		invalid = 1;
 		goto done;
 	    }
-	    if (Max_Search_Results > 0 && max_results > Max_Search_Results)
+	    if ((Max_Search_Results > 0 && max_results > Max_Search_Results)
+		    /* don't let the user pick 0 to force unlimited results! */
+		    || max_results == 0)
 		max_results = Max_Search_Results;
 	}
 	else if (!strcasecmp ("type", arg))
@@ -809,7 +849,7 @@ search_internal (CONNECTION * con, USER * user, char *id, char *pkt)
 	    }
 	    else
 	    {
-		log ("fdb_search: ERROR, drscholl fucked up if you see this");
+		log_message ("fdb_search: ERROR, drscholl fucked up if you see this");
 		goto done;
 	    }
 
@@ -823,7 +863,7 @@ search_internal (CONNECTION * con, USER * user, char *id, char *pkt)
 	}
 	else
 	{
-	    log ("search: %s: unknown search argument", arg);
+	    log_message ("search: %s: unknown search argument", arg);
 	    invalid = 1;
 	    goto done;
 	}
@@ -891,11 +931,19 @@ HANDLER (search)
      */
     if (con->uopt->searches < 0)
     {
-	log ("search: ERROR, con->uopt->searches < 0!!!");
+	log_message ("search: ERROR, con->uopt->searches < 0!!!");
 	send_cmd (con, MSG_SERVER_NOSUCH, "search failed: server error");
 	con->uopt->searches = 0;
 	return;
     }
+
+    if (! option (ON_ALLOW_SHARE))
+    {
+	/* sharing is not allowed on this server */
+	send_cmd (con, MSG_SERVER_SEARCH_END, "");
+	return;
+    }
+
     /* if Max_Searches is > 0, we only allow clients to have a certain small
      * number of pending search requests.  Some abusive clients will tend
      * to issues multiple search requests at a time.
@@ -908,7 +956,7 @@ HANDLER (search)
     }
     if (con->uopt->searches == 0x7fffffff)
     {
-	log ("search: ERROR, con->uopt->searches will overflow!!!");
+	log_message ("search: ERROR, con->uopt->searches will overflow!!!");
 	send_cmd (con, MSG_SERVER_NOSUCH, "search failed: server error");
 	return;
     }
@@ -951,18 +999,26 @@ HANDLER (remote_search)
 	/* try to terminate the search anyway */
 	if (id)
 	    send_cmd (con, MSG_SERVER_REMOTE_SEARCH_END, "%s", id);
-	log ("remote_search: too few parameters");
+	log_message ("remote_search: too few parameters");
 	return;
     }
     user = hash_lookup (Users, nick);
     if (!user)
     {
-	log ("remote_search: could not locate user %s (from %s)", nick,
+	log_message ("remote_search: could not locate user %s (from %s)", nick,
 	     con->host);
 	/* imediately notify the peer that we don't have any matches */
 	send_cmd (con, MSG_SERVER_REMOTE_SEARCH_END, "%s", id);
 	return;
     }
+
+    if (! option (ON_ALLOW_SHARE))
+    {
+	/* sharing is not allowed on this server */
+	send_cmd (con, MSG_SERVER_REMOTE_SEARCH_END, "%s", id);
+	return;
+    }
+
 #ifdef ROUTING_ONLY
     Search_Count++;
     /* no local files, just pass this request to the peer servers and
@@ -996,14 +1052,14 @@ HANDLER (remote_search_result)
 
     if (ac != 8)
     {
-	log ("remote_search_result: wrong number of args");
+	log_message ("remote_search_result: wrong number of args");
 	print_args (ac, av);
 	return;
     }
     search = find_search (av[0]);
     if (!search)
     {
-	log ("remote_search_result: could not find search id %s", av[0]);
+	log_message ("remote_search_result: could not find search id %s", av[0]);
 	return;
     }
     if (ISUSER (search->con))
@@ -1012,7 +1068,7 @@ HANDLER (remote_search_result)
 	user = hash_lookup (Users, av[1]);
 	if (!user)
 	{
-	    log ("remote_search_result: could not find user %s (from %s)",
+	    log_message ("remote_search_result: could not find user %s (from %s)",
 		 av[1], con->host);
 	    return;
 	}
@@ -1057,7 +1113,7 @@ unlink_search (LIST ** list, int send_ack)
     FREE (tmp);
 
     if (Pending_Searches == 0)
-	log ("search_end: ERROR, Pending_Searches == 0!!!");
+	log_message ("search_end: ERROR, Pending_Searches == 0!!!");
     else
 	Pending_Searches--;
 }
@@ -1086,7 +1142,7 @@ HANDLER (remote_search_end)
     }
     if (!*list)
     {
-	log ("remote_end_match: could not find entry for search id %s", id);
+	log_message ("remote_end_match: could not find entry for search id %s", id);
 	return;
     }
     search = (*list)->data;
@@ -1145,5 +1201,5 @@ expire_searches (void)
 	expired++;
     }
     if (expired)
-	log ("expire_searches: %d stale entries", expired);
+	log_message ("expire_searches: %d stale entries", expired);
 }
