@@ -2,12 +2,16 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: spyserv.c,v 1.10 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: spyserv.c,v 1.11 2001/03/06 06:49:53 drscholl Exp $ */
 
 /* a simple proxy server to spy on the traffic between client and server.  this
    is a lot easier than using tcpdump.  use the fake metaserver to redirect
    clients to this server */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <unistd.h>
