@@ -4,7 +4,11 @@
 
    Modified by drscholl@users.sourceforge.net 2/29/2000.
 
-   $Id: timer.c,v 1.9 2001/02/13 08:41:15 drscholl Exp $ */
+   $Id: timer.c,v 1.10 2001/03/06 06:49:53 drscholl Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <time.h>
 #include <stdlib.h>
