@@ -2,12 +2,16 @@
    This is free software distributed under the terms of the
    GNU Public License.  See the file COPYING for details.
 
-   $Id: usermode.c,v 1.20 2001/02/15 08:39:45 drscholl Exp $ */
+   $Id: usermode.c,v 1.21 2001/03/06 06:49:53 drscholl Exp $ */
 
 /*
  * written by Colten Edwards.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
